package anbo.easj.dk.sensorexample;

import android.app.Activity;
import android.content.Context;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.os.Bundle;
import android.util.Log;
import android.widget.TextView;

import java.util.List;

import static android.hardware.Sensor.*;

// http://developer.android.com/guide/topics/sensors/sensors_overview.html
// http://developer.android.com/guide/topics/sensors/sensors_environment.html
public class MainActivity extends Activity implements SensorEventListener {
    private static final int[] CENSOR_TYPES = {TYPE_ACCELEROMETER, TYPE_AMBIENT_TEMPERATURE, TYPE_GRAVITY, TYPE_GYROSCOPE};
    private SensorManager mSensorManager;
    private Sensor mPressure, mLight, mGravity, mAcceleration, mProximity, mMagneticField;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        mSensorManager = (SensorManager) getSystemService(Context.SENSOR_SERVICE);
        TextView messageView = (TextView) findViewById(R.id.messageView);
        // http://stackoverflow.com/questions/2858161/display-an-android-sensors-list
        List<Sensor> sensorList = mSensorManager.getSensorList(Sensor.TYPE_ALL);
        // messageView.setText(sensorList.toString());
        StringBuffer sb = new StringBuffer();
        for (Sensor sensor : sensorList) {
            //sb.append(sensor.getStringType()); // API 20++
            sb.append(sensor.toString());
            sb.append("\n");
        }

        messageView.setText(sb);
        getCensors();
    }


    private void getCensors() {
        mPressure = mSensorManager.getDefaultSensor(Sensor.TYPE_PRESSURE);
        mLight = mSensorManager.getDefaultSensor(Sensor.TYPE_LIGHT);
        mGravity = mSensorManager.getDefaultSensor(Sensor.TYPE_GRAVITY);
        mAcceleration = mSensorManager.getDefaultSensor(Sensor.TYPE_ACCELEROMETER);
        mProximity = mSensorManager.getDefaultSensor(Sensor.TYPE_PROXIMITY);
        mMagneticField = mSensorManager.getDefaultSensor(Sensor.TYPE_MAGNETIC_FIELD);

    }

    @Override
    public void onSensorChanged(SensorEvent event) {
        switch (event.sensor.getType()) {
            case Sensor.TYPE_PRESSURE:
                float millibars_of_pressure = event.values[0];
                Log.d("MINE", "Pressure " + millibars_of_pressure);
                break;
            case Sensor.TYPE_LIGHT:
                float light = event.values[0];
                Log.d("MINE", "Light " + light);
                break;
            case Sensor.TYPE_ACCELEROMETER:
                float x = event.values[0];
                float y = event.values[1];
                float z = event.values[2];
                Log.d("MINE", "Acceleration: " + x + " " + y + " " + z);
                break;
            case Sensor.TYPE_PROXIMITY:
                float distance_in_cm = event.values[0];
                Log.d("MINE", "Proximity " + distance_in_cm + " cm");
                break;

            case Sensor.TYPE_MAGNETIC_FIELD:
                x = event.values[0];
                y = event.values[1];
                z = event.values[2];
                Log.d("MINE", "Magnetic field: " + x + " " + y + " " + z);
                break;
        }

    }

    @Override
    public void onAccuracyChanged(Sensor sensor, int accuracy) { /* empty */ }

    @Override
    protected void onResume() {
        super.onResume();
       mSensorManager.registerListener(this, mPressure, SensorManager.SENSOR_DELAY_NORMAL);
        mSensorManager.registerListener(this, mLight, SensorManager.SENSOR_DELAY_NORMAL);
        //mSensorManager.registerListener(this, mGravity, SensorManager.SENSOR_DELAY_NORMAL);
        //mSensorManager.registerListener(this, mAcceleration, SensorManager.SENSOR_DELAY_NORMAL);
        mSensorManager.registerListener(this, mProximity, SensorManager.SENSOR_DELAY_NORMAL);
        //mSensorManager.registerListener(this, mMagneticField, SensorManager.SENSOR_DELAY_NORMAL);
    }

    @Override
    protected void onPause() {
        // Be sure to unregister the sensor when the activity pauses.
        super.onPause();
        mSensorManager.unregisterListener(this);
    }
}
